#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rate-limit
version:              1.4.3
visibility:           public
id:                   rate-limit-1.4.3-6ydvOkN3EwQLZ5xS3sVlHp
key:                  rate-limit-1.4.3-6ydvOkN3EwQLZ5xS3sVlHp
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/rate-limit
synopsis:             A basic library for rate-limiting IO actions.
description:
    In many cases, it is useful, necessary, or simply nice to limit how
    frequently you perform some action. For example, you may want to limit
    how often your program makes a request of some web site. This library
    is intended as a general-purpose mechanism for rate-limiting IO actions.

category:             Control
abi:                  90ecb5d84d063bcebd93f4c196d81f2b
exposed:              True
exposed-modules:      Control.RateLimit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rate-limit-1.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rate-limit-1.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rate-limit-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rate-limit
hs-libraries:         HSrate-limit-1.4.3-6ydvOkN3EwQLZ5xS3sVlHp
depends:
    base-4.18.2.1 stm-2.5.1.0 time-1.12.2
    time-units-1.0.0-5DRkw9RXZDICp7PYN09sTv

haddock-interfaces:   /usr/share/doc/haskell-rate-limit/html/rate-limit.haddock
haddock-html:         /usr/share/doc/haskell-rate-limit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

